pub struct JavaAbstractMap<'mc>(_, _);
This class provides a skeletal implementation of the Map interface, to minimize the effort required to implement this interface.

To implement an unmodifiable map, the programmer needs only to extend this class and provide an implementation for the entrySet method, which returns a set-view of the map's mappings. Typically, the returned set will, in turn, be implemented atop AbstractSet. This set should not support the add or remove methods, and its iterator should not support the remove method.

To implement a modifiable map, the programmer must additionally override this class's put method (which otherwise throws an UnsupportedOperationException), and the iterator returned by entrySet().iterator() must additionally implement its remove method.

The programmer should generally provide a void (no argument) and map constructor, as per the recommendation in the Map interface specification.

The documentation for each non-abstract method in this class describes its implementation in detail. Each of these methods may be overridden if the map being implemented admits a more efficient implementation.

This class is a member of the Java Collections Framework.

Implementations

source

impl<'mc> JavaAbstractMap<'mc>

source

pub fn from_raw( env: &SharedJNIEnv<'mc>, obj: JObject<'mc> ) -> Result<Self, Box<dyn Error>>

source

pub fn remove_with_object( &mut self, arg0: Option<JObject<'mc>>, arg1: Option<JObject<'mc>> ) -> Result<bool, Box<dyn Error>>

source

pub fn get( &mut self, arg0: JObject<'mc> ) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn put( &mut self, arg0: JObject<'mc>, arg1: JObject<'mc> ) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn equals(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>

source

pub fn to_string(&mut self) -> Result<String, Box<dyn Error>>

source

pub fn values(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn hash_code(&mut self) -> Result<i32, Box<dyn Error>>

source

pub fn clear(&mut self) -> Result<(), Box<dyn Error>>

source

pub fn is_empty(&mut self) -> Result<bool, Box<dyn Error>>

source

pub fn size(&mut self) -> Result<i32, Box<dyn Error>>

source

pub fn entry_set(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn put_all(&mut self, arg0: JObject<'mc>) -> Result<(), Box<dyn Error>>

source

pub fn contains_key( &mut self, arg0: JObject<'mc> ) -> Result<bool, Box<dyn Error>>

source

pub fn key_set(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn contains_value( &mut self, arg0: JObject<'mc> ) -> Result<bool, Box<dyn Error>>

source

pub fn wait( &mut self, arg0: Option<i64>, arg1: Option<i32> ) -> Result<(), Box<dyn Error>>

source

pub fn class(&mut self) -> Result<JClass<'mc>, Box<dyn Error>>

source

pub fn notify(&mut self) -> Result<(), Box<dyn Error>>

source

pub fn notify_all(&mut self) -> Result<(), Box<dyn Error>>

source

pub fn replace_with_object( &mut self, arg0: JObject<'mc>, arg1: Option<JObject<'mc>>, arg2: Option<JObject<'mc>> ) -> Result<bool, Box<dyn Error>>

source

pub fn replace_all(&mut self, arg0: JObject<'mc>) -> Result<(), Box<dyn Error>>

source

pub fn merge( &mut self, arg0: JObject<'mc>, arg1: JObject<'mc>, arg2: JObject<'mc> ) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn put_if_absent( &mut self, arg0: JObject<'mc>, arg1: JObject<'mc> ) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn compute( &mut self, arg0: JObject<'mc>, arg1: JObject<'mc> ) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn for_each(&mut self, arg0: JObject<'mc>) -> Result<(), Box<dyn Error>>

source

pub fn compute_if_absent( &mut self, arg0: JObject<'mc>, arg1: JObject<'mc> ) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn get_or_default( &mut self, arg0: JObject<'mc>, arg1: JObject<'mc> ) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn compute_if_present( &mut self, arg0: JObject<'mc>, arg1: JObject<'mc> ) -> Result<JObject<'mc>, Box<dyn Error>>