pub struct JavaAbstractQueue<'mc>(_, _);
This class provides skeletal implementations of some Queue operations. The implementations in this class are appropriate when the base implementation does not allow null elements. Methods add, remove, and element are based on offer, poll, and peek, respectively, but throw exceptions instead of indicating failure via false or null returns.

A Queue implementation that extends this class must minimally define a method Queue.offer(E) which does not permit insertion of null elements, along with methods Queue.peek(), Queue.poll(), Collection.size(), and Collection.iterator(). Typically, additional methods will be overridden as well. If these requirements cannot be met, consider instead subclassing AbstractCollection.

This class is a member of the Java Collections Framework.

Implementations

source

impl<'mc> JavaAbstractQueue<'mc>

source

pub fn from_raw( env: &SharedJNIEnv<'mc>, obj: JObject<'mc> ) -> Result<Self, Box<dyn Error>>

source

pub fn add(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>

source

pub fn remove( &mut self, arg0: Option<JObject<'mc>> ) -> Result<bool, Box<dyn Error>>

source

pub fn clear(&mut self) -> Result<(), Box<dyn Error>>

source

pub fn add_all(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>

source

pub fn element(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn to_string(&mut self) -> Result<String, Box<dyn Error>>

source

pub fn is_empty(&mut self) -> Result<bool, Box<dyn Error>>

source

pub fn size(&mut self) -> Result<i32, Box<dyn Error>>

source

pub fn iterator(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn contains(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>

source

pub fn remove_all(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>

source

pub fn retain_all(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>

source

pub fn contains_all( &mut self, arg0: JObject<'mc> ) -> Result<bool, Box<dyn Error>>

source

pub fn wait( &mut self, arg0: Option<i64>, arg1: Option<i32> ) -> Result<(), Box<dyn Error>>

source

pub fn equals(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>

source

pub fn hash_code(&mut self) -> Result<i32, Box<dyn Error>>

source

pub fn class(&mut self) -> Result<JClass<'mc>, Box<dyn Error>>

source

pub fn notify(&mut self) -> Result<(), Box<dyn Error>>

source

pub fn notify_all(&mut self) -> Result<(), Box<dyn Error>>

source

pub fn stream(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn spliterator(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn remove_if(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>

source

pub fn parallel_stream(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn for_each(&mut self, arg0: JObject<'mc>) -> Result<(), Box<dyn Error>>

source

pub fn offer(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>

source

pub fn poll(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>

source

pub fn peek(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>