Module blackboxmc_java::util::function
source · Structs
- Represents an operation that accepts two input arguments and returns no result. This is the two-arity specialization of
Consumer. Unlike most other functional interfaces,BiConsumeris expected to operate via side-effects. - Represents a function that accepts two arguments and produces a result. This is the two-arity specialization of
Function. - Represents a predicate (boolean-valued function) of two arguments. This is the two-arity specialization of
Predicate. - Represents an operation upon two operands of the same type, producing a result of the same type as the operands. This is a specialization of
BiFunctionfor the case where the operands and the result are all of the same type. - Represents a supplier of
boolean-valued results. This is theboolean-producing primitive specialization ofSupplier. - Represents an operation that accepts a single input argument and returns no result. Unlike most other functional interfaces,
Consumeris expected to operate via side-effects. - Represents an operation upon two
double-valued operands and producing adouble-valued result. This is the primitive type specialization ofBinaryOperatorfordouble. - Represents an operation that accepts a single
double-valued argument and returns no result. This is the primitive type specialization ofConsumerfordouble. Unlike most other functional interfaces,DoubleConsumeris expected to operate via side-effects. - Represents a function that accepts a double-valued argument and produces a result. This is the
double-consuming primitive specialization forFunction. - Represents a predicate (boolean-valued function) of one
double-valued argument. This is thedouble-consuming primitive type specialization ofPredicate. - Represents a supplier of
double-valued results. This is thedouble-producing primitive specialization ofSupplier. - Represents a function that accepts a double-valued argument and produces an int-valued result. This is the
double-to-intprimitive specialization forFunction. - Represents a function that accepts a double-valued argument and produces a long-valued result. This is the
double-to-longprimitive specialization forFunction. - Represents an operation on a single
double-valued operand that produces adouble-valued result. This is the primitive type specialization ofUnaryOperatorfordouble. - Represents a function that accepts one argument and produces a result.
- Represents an operation upon two
int-valued operands and producing anint-valued result. This is the primitive type specialization ofBinaryOperatorforint. - Represents an operation that accepts a single
int-valued argument and returns no result. This is the primitive type specialization ofConsumerforint. Unlike most other functional interfaces,IntConsumeris expected to operate via side-effects. - Represents a function that accepts an int-valued argument and produces a result. This is the
int-consuming primitive specialization forFunction. - Represents a predicate (boolean-valued function) of one
int-valued argument. This is theint-consuming primitive type specialization ofPredicate. - Represents a supplier of
int-valued results. This is theint-producing primitive specialization ofSupplier. - Represents a function that accepts an int-valued argument and produces a double-valued result. This is the
int-to-doubleprimitive specialization forFunction. - Represents a function that accepts an int-valued argument and produces a long-valued result. This is the
int-to-longprimitive specialization forFunction. - Represents an operation on a single
int-valued operand that produces anint-valued result. This is the primitive type specialization ofUnaryOperatorforint. - Represents an operation upon two
long-valued operands and producing along-valued result. This is the primitive type specialization ofBinaryOperatorforlong. - Represents an operation that accepts a single
long-valued argument and returns no result. This is the primitive type specialization ofConsumerforlong. Unlike most other functional interfaces,LongConsumeris expected to operate via side-effects. - Represents a function that accepts a long-valued argument and produces a result. This is the
long-consuming primitive specialization forFunction. - Represents a predicate (boolean-valued function) of one
long-valued argument. This is thelong-consuming primitive type specialization ofPredicate. - Represents a supplier of
long-valued results. This is thelong-producing primitive specialization ofSupplier. - Represents a function that accepts a long-valued argument and produces a double-valued result. This is the
long-to-doubleprimitive specialization forFunction. - Represents a function that accepts a long-valued argument and produces an int-valued result. This is the
long-to-intprimitive specialization forFunction. - Represents an operation on a single
long-valued operand that produces along-valued result. This is the primitive type specialization ofUnaryOperatorforlong. - Represents an operation that accepts an object-valued and a
double-valued argument, and returns no result. This is the(reference, double)specialization ofBiConsumer. Unlike most other functional interfaces,ObjDoubleConsumeris expected to operate via side-effects. - Represents an operation that accepts an object-valued and a
int-valued argument, and returns no result. This is the(reference, int)specialization ofBiConsumer. Unlike most other functional interfaces,ObjIntConsumeris expected to operate via side-effects. - Represents an operation that accepts an object-valued and a
long-valued argument, and returns no result. This is the(reference, long)specialization ofBiConsumer. Unlike most other functional interfaces,ObjLongConsumeris expected to operate via side-effects. - Represents a predicate (boolean-valued function) of one argument.
- Represents a supplier of results.
- Represents a function that accepts two arguments and produces a double-valued result. This is the
double-producing primitive specialization forBiFunction. - Represents a function that produces a double-valued result. This is the
double-producing primitive specialization forFunction. - Represents a function that accepts two arguments and produces an int-valued result. This is the
int-producing primitive specialization forBiFunction. - Represents a function that produces an int-valued result. This is the
int-producing primitive specialization forFunction. - Represents a function that accepts two arguments and produces a long-valued result. This is the
long-producing primitive specialization forBiFunction. - Represents a function that produces a long-valued result. This is the
long-producing primitive specialization forFunction. - Represents an operation on a single operand that produces a result of the same type as its operand. This is a specialization of
Functionfor the case where the operand and result are of the same type.