This Handler publishes log records to System.err. By default the SimpleFormatter is used to generate brief summaries.
ErrorManager objects can be attached to Handlers to process any error that occurs on a Handler during Logging.
A Filter can be used to provide fine grain control over what is logged, beyond the control provided by log levels.
A Formatter provides support for formatting LogRecords.
A Handler object takes log messages from a Logger and exports them. It might for example, write them to a console or write them to a file, or send them to a network logging service, or forward them to an OS log, or whatever.
The Level class defines a set of standard logging levels that can be used to control logging output. The logging Level objects are ordered and are specified by ordered integers. Enabling logging at a given level also enables logging at all higher levels.
LogRecord objects are used to pass logging requests between the logging framework and individual log Handlers.
A Logger object is used to log messages for a specific system or application component. Loggers are normally named, using a hierarchical dot-separated namespace. Logger names can be arbitrary strings, but they should normally be based on the package name or class name of the logged component, such as java.net or javax.swing. In addition it is possible to create “anonymous” Loggers that are not stored in the Logger namespace.
The permission which the SecurityManager will check when code that is running with a SecurityManager calls one of the logging control methods (such as Logger.setLevel).
Handler that buffers requests in a circular buffer in memory.
Print a brief summary of the LogRecord in a human readable format. The summary will typically be 1 or 2 lines.
Simple network logging Handler.
Stream based logging Handler.
Format a LogRecord into a standard XML format.