pub struct JavaAbstractMapSimpleEntry<'mc>(/* private fields */);Expand description
An Entry maintaining a key and a value. The value may be changed using the setValue method. This class facilitates the process of building custom map implementations. For example, it may be convenient to return arrays of SimpleEntry instances in method Map.entrySet().toArray.
Implementations
Sourceimpl<'mc> JavaAbstractMapSimpleEntry<'mc>
impl<'mc> JavaAbstractMapSimpleEntry<'mc>
pub fn new_with_object( jni: &SharedJNIEnv<'mc>, arg0: JObject<'mc>, arg1: Option<JObject<'mc>>, ) -> Result<JavaAbstractMapSimpleEntry<'mc>, Box<dyn Error>>
pub fn equals(&self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn hash_code(&self) -> Result<i32, Box<dyn Error>>
pub fn value(&self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn key(&self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn set_value( &self, arg0: JObject<'mc>, ) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn comparing_by_key_with_comparator( jni: &SharedJNIEnv<'mc>, arg0: Option<impl Into<JavaComparator<'mc>>>, ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn comparing_by_value_with_comparator( jni: &SharedJNIEnv<'mc>, arg0: Option<impl Into<JavaComparator<'mc>>>, ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn copy_of( jni: &SharedJNIEnv<'mc>, arg0: impl Into<JavaMapEntry<'mc>>, ) -> Result<JavaMapEntry<'mc>, Box<dyn Error>>
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>