pub struct JavaUUID<'mc>(/* private fields */);Expand description
A class that represents an immutable universally unique identifier (UUID). A UUID represents a 128-bit value.
There exist different variants of these global identifiers. The methods of this class are for manipulating the Leach-Salz variant, although the constructors allow the creation of any variant of UUID (described below).
The layout of a variant 2 (Leach-Salz) UUID is as follows: The most significant long consists of the following unsigned fields:
0xFFFFFFFF00000000 time_low 0x00000000FFFF0000 time_mid 0x000000000000F000 version 0x0000000000000FFF time_hiThe least significant long consists of the following unsigned fields:
0xC000000000000000 variant 0x3FFF000000000000 clock_seq 0x0000FFFFFFFFFFFF node
The variant field contains a value which identifies the layout of the UUID. The bit layout described above is valid only for a UUID with a variant value of 2, which indicates the Leach-Salz variant.
The version field holds a value that describes the type of this UUID. There are four different basic types of UUIDs: time-based, DCE security, name-based, and randomly generated UUIDs. These types have a version value of 1, 2, 3 and 4, respectively.
For more information including algorithms used to create UUIDs, see RFC 4122: A Universally Unique IDentifier (UUID) URN Namespace, section 4.2 "Algorithms for Creating a Time-Based UUID".
Implementations
Sourceimpl<'mc> JavaUUID<'mc>
impl<'mc> JavaUUID<'mc>
pub fn new( jni: &SharedJNIEnv<'mc>, arg0: i64, arg1: i64, ) -> Result<JavaUUID<'mc>, Box<dyn Error>>
pub fn name_uuidfrom_bytes( jni: &SharedJNIEnv<'mc>, arg0: Vec<i8>, ) -> Result<JavaUUID<'mc>, Box<dyn Error>>
pub fn least_significant_bits(&self) -> Result<i64, Box<dyn Error>>
pub fn most_significant_bits(&self) -> Result<i64, Box<dyn Error>>
pub fn clock_sequence(&self) -> Result<i32, Box<dyn Error>>
pub fn variant(&self) -> Result<i32, Box<dyn Error>>
pub fn random_uuid( jni: &SharedJNIEnv<'mc>, ) -> Result<JavaUUID<'mc>, Box<dyn Error>>
pub fn from_string( jni: &SharedJNIEnv<'mc>, arg0: impl Into<String>, ) -> Result<JavaUUID<'mc>, Box<dyn Error>>
pub fn equals(&self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn version(&self) -> Result<i32, Box<dyn Error>>
pub fn hash_code(&self) -> Result<i32, Box<dyn Error>>
pub fn compare_to_with_uuid( &self, arg0: impl Into<JavaUUID<'mc>>, ) -> Result<i32, Box<dyn Error>>
pub fn timestamp(&self) -> Result<i64, Box<dyn Error>>
pub fn node(&self) -> Result<i64, Box<dyn Error>>
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>