Struct blackboxmc_java::JavaAbstractSet
source · pub struct JavaAbstractSet<'mc>(_, _);Expand description
This class provides a skeletal implementation of the Set interface to minimize the effort required to implement this interface.
The process of implementing a set by extending this class is identical to that of implementing a Collection by extending AbstractCollection, except that all of the methods and constructors in subclasses of this class must obey the additional constraints imposed by the Set interface (for instance, the add method must not permit addition of multiple instances of an object to a set).
Note that this class does not override any of the implementations from the AbstractCollection class. It merely adds implementations for equals and hashCode.
This class is a member of the Java Collections Framework.
Implementations
sourceimpl<'mc> JavaAbstractSet<'mc>
impl<'mc> JavaAbstractSet<'mc>
pub fn from_raw( env: &SharedJNIEnv<'mc>, obj: JObject<'mc> ) -> Result<Self, Box<dyn Error>>
pub fn equals(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn hash_code(&mut self) -> Result<i32, Box<dyn Error>>
pub fn remove_all(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn add(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn remove(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn to_string(&mut self) -> Result<String, Box<dyn Error>>
pub fn clear(&mut self) -> Result<(), Box<dyn Error>>
pub fn is_empty(&mut self) -> Result<bool, Box<dyn Error>>
pub fn size(&mut self) -> Result<i32, Box<dyn Error>>
pub fn iterator(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn contains(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn add_all(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn retain_all(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn contains_all( &mut self, arg0: JObject<'mc> ) -> Result<bool, Box<dyn Error>>
pub fn wait( &mut self, arg0: Option<i64>, arg1: Option<i32> ) -> Result<(), Box<dyn Error>>
pub fn class(&mut self) -> Result<JClass<'mc>, Box<dyn Error>>
pub fn notify(&mut self) -> Result<(), Box<dyn Error>>
pub fn notify_all(&mut self) -> Result<(), Box<dyn Error>>
pub fn stream(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn spliterator(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn remove_if(&mut self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn parallel_stream(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn for_each(&mut self, arg0: JObject<'mc>) -> Result<(), Box<dyn Error>>