Struct blackboxmc_java::JavaEnumeration
source · pub struct JavaEnumeration<'mc>(_, _);Expand description
An object that implements the Enumeration interface generates a series of elements, one at a time. Successive calls to the nextElement method return successive elements of the series.
For example, to print all elements of a Vector<E> v:
for (Enumeration<E> e = v.elements(); e.hasMoreElements();) System.out.println(e.nextElement());
Methods are provided to enumerate through the elements of a vector, the keys of a hashtable, and the values in a hashtable. Enumerations are also used to specify the input streams to a SequenceInputStream.
NOTE: The functionality of this interface is duplicated by the Iterator interface. In addition, Iterator adds an optional remove operation, and has shorter method names. New implementations should consider using Iterator in preference to Enumeration.
This is a representation of an abstract class.
Implementations
sourceimpl<'mc> JavaEnumeration<'mc>
impl<'mc> JavaEnumeration<'mc>
pub fn from_raw( env: &SharedJNIEnv<'mc>, obj: JObject<'mc> ) -> Result<Self, Box<dyn Error>>
pub fn as_iterator(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn has_more_elements(&mut self) -> Result<bool, Box<dyn Error>>
pub fn next_element(&mut self) -> Result<JObject<'mc>, Box<dyn Error>>