Struct blackboxmc_java::util::logging::JavaLevel
source · pub struct JavaLevel<'mc>(_, _);Expand description
The Level class defines a set of standard logging levels that can be used to control logging output. The logging Level objects are ordered and are specified by ordered integers. Enabling logging at a given level also enables logging at all higher levels.
Clients should normally use the predefined Level constants such as Level.SEVERE.
The levels in descending order are:
- SEVERE (highest value)
- WARNING
- INFO
- CONFIG
- FINE
- FINER
- FINEST (lowest value)
It is possible for third parties to define additional logging levels by subclassing Level. In such cases subclasses should take care to chose unique integer level values and to ensure that they maintain the Object uniqueness property across serialization by defining a suitable readResolve method.
Implementations
sourceimpl<'mc> JavaLevel<'mc>
impl<'mc> JavaLevel<'mc>
pub fn resource_bundle_name(&self) -> Result<String, Box<dyn Error>>
pub fn parse( jni: &SharedJNIEnv<'mc>, arg0: impl Into<String> ) -> Result<JavaLevel<'mc>, Box<dyn Error>>
pub fn name(&self) -> Result<String, Box<dyn Error>>
pub fn equals(&self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn hash_code(&self) -> Result<i32, Box<dyn Error>>
pub fn int_value(&self) -> Result<i32, Box<dyn Error>>
pub fn localized_name(&self) -> Result<String, Box<dyn Error>>
pub fn wait_with_long( &self, arg0: Option<i64>, arg1: Option<i32> ) -> Result<(), Box<dyn Error>>
pub fn notify(&self) -> Result<(), Box<dyn Error>>
pub fn notify_all(&self) -> Result<(), Box<dyn Error>>
pub fn instance_of<A>(&self, other: A) -> boolwhere A: JNIProvidesClassName,