Struct blackboxmc_java::util::JavaAbstractMapSimpleEntry
source · pub struct JavaAbstractMapSimpleEntry<'mc>(_, _);Expand description
An Entry maintaining a key and a value. The value may be changed using the setValue method. This class facilitates the process of building custom map implementations. For example, it may be convenient to return arrays of SimpleEntry instances in method Map.entrySet().toArray.
Implementations
sourceimpl<'mc> JavaAbstractMapSimpleEntry<'mc>
impl<'mc> JavaAbstractMapSimpleEntry<'mc>
pub fn new_with_object( jni: &SharedJNIEnv<'mc>, arg0: JObject<'mc>, arg1: Option<JObject<'mc>> ) -> Result<JavaAbstractMapSimpleEntry<'mc>, Box<dyn Error>>
pub fn equals(&self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn hash_code(&self) -> Result<i32, Box<dyn Error>>
pub fn value(&self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn key(&self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn set_value( &self, arg0: JObject<'mc> ) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn wait_with_long( &self, arg0: Option<i64>, arg1: Option<i32> ) -> Result<(), Box<dyn Error>>
pub fn notify(&self) -> Result<(), Box<dyn Error>>
pub fn notify_all(&self) -> Result<(), Box<dyn Error>>
pub fn instance_of<A>(&self, other: A) -> boolwhere A: JNIProvidesClassName,