Struct blackboxmc_java::util::JavaArrayList
source · pub struct JavaArrayList<'mc>(_, _);Expand description
Resizable-array implementation of the List interface. Implements all optional list operations, and permits all elements, including null. In addition to implementing the List interface, this class provides methods to manipulate the size of the array that is used internally to store the list. (This class is roughly equivalent to Vector, except that it is unsynchronized.)
The size, isEmpty, get, set, iterator, and listIterator operations run in constant time. The add operation runs in amortized constant time, that is, adding n elements requires O(n) time. All of the other operations run in linear time (roughly speaking). The constant factor is low compared to that for the LinkedList implementation.
Each ArrayList instance has a capacity. The capacity is the size of the array used to store the elements in the list. It is always at least as large as the list size. As elements are added to an ArrayList, its capacity grows automatically. The details of the growth policy are not specified beyond the fact that adding an element has constant amortized time cost.
An application can increase the capacity of an ArrayList instance before adding a large number of elements using the ensureCapacity operation. This may reduce the amount of incremental reallocation.
Note that this implementation is not synchronized. If multiple threads access an ArrayList instance concurrently, and at least one of the threads modifies the list structurally, it must be synchronized externally. (A structural modification is any operation that adds or deletes one or more elements, or explicitly resizes the backing array; merely setting the value of an element is not a structural modification.) This is typically accomplished by synchronizing on some object that naturally encapsulates the list. If no such object exists, the list should be "wrapped" using the Collections.synchronizedList method. This is best done at creation time, to prevent accidental unsynchronized access to the list:
List list = Collections.synchronizedList(new ArrayList(...));
The iterators returned by this class's iterator and listIterator methods are fail-fast: if the list is structurally modified at any time after the iterator is created, in any way except through the iterator's own remove or add methods, the iterator will throw a ConcurrentModificationException. Thus, in the face of concurrent modification, the iterator fails quickly and cleanly, rather than risking arbitrary, non-deterministic behavior at an undetermined time in the future.
Note that the fail-fast behavior of an iterator cannot be guaranteed as it is, generally speaking, impossible to make any hard guarantees in the presence of unsynchronized concurrent modification. Fail-fast iterators throw ConcurrentModificationException on a best-effort basis. Therefore, it would be wrong to write a program that depended on this exception for its correctness: the fail-fast behavior of iterators should be used only to detect bugs.
This class is a member of the Java Collections Framework.
Implementations
sourceimpl<'mc> JavaArrayList<'mc>
impl<'mc> JavaArrayList<'mc>
pub fn new_with_int( jni: &SharedJNIEnv<'mc>, arg0: Option<i32> ) -> Result<JavaArrayList<'mc>, Box<dyn Error>>
pub fn add_with_int( &self, arg0: i32, arg1: Option<JObject<'mc>> ) -> Result<(), Box<dyn Error>>
pub fn remove_with_int(&self, arg0: i32) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn get(&self, arg0: i32) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn equals(&self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn hash_code(&self) -> Result<i32, Box<dyn Error>>
pub fn clone(&self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn index_of(&self, arg0: JObject<'mc>) -> Result<i32, Box<dyn Error>>
pub fn clear(&self) -> Result<(), Box<dyn Error>>
pub fn last_index_of(&self, arg0: JObject<'mc>) -> Result<i32, Box<dyn Error>>
pub fn is_empty(&self) -> Result<bool, Box<dyn Error>>
pub fn replace_all( &self, arg0: impl Into<JavaUnaryOperator<'mc>> ) -> Result<(), Box<dyn Error>>
pub fn size(&self) -> Result<i32, Box<dyn Error>>
pub fn sub_list( &self, arg0: i32, arg1: i32 ) -> Result<JavaList<'mc>, Box<dyn Error>>
pub fn iterator(&self) -> Result<JavaIterator<'mc>, Box<dyn Error>>
pub fn contains(&self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn add_all_with_int( &self, arg0: i32, arg1: Option<impl Into<JavaCollection<'mc>>> ) -> Result<bool, Box<dyn Error>>
pub fn set( &self, arg0: i32, arg1: JObject<'mc> ) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn for_each( &self, arg0: impl Into<JavaConsumer<'mc>> ) -> Result<(), Box<dyn Error>>
pub fn ensure_capacity(&self, arg0: i32) -> Result<(), Box<dyn Error>>
pub fn trim_to_size(&self) -> Result<(), Box<dyn Error>>
pub fn remove_if( &self, arg0: impl Into<JavaPredicate<'mc>> ) -> Result<bool, Box<dyn Error>>
pub fn sort( &self, arg0: impl Into<JavaComparator<'mc>> ) -> Result<(), Box<dyn Error>>
pub fn remove_all( &self, arg0: impl Into<JavaCollection<'mc>> ) -> Result<bool, Box<dyn Error>>
pub fn retain_all( &self, arg0: impl Into<JavaCollection<'mc>> ) -> Result<bool, Box<dyn Error>>
pub fn list_iterator_with_int( &self, arg0: Option<i32> ) -> Result<JavaListIterator<'mc>, Box<dyn Error>>
pub fn contains_all( &self, arg0: impl Into<JavaCollection<'mc>> ) -> Result<bool, Box<dyn Error>>
pub fn wait_with_long( &self, arg0: Option<i64>, arg1: Option<i32> ) -> Result<(), Box<dyn Error>>
pub fn notify(&self) -> Result<(), Box<dyn Error>>
pub fn notify_all(&self) -> Result<(), Box<dyn Error>>
pub fn instance_of<A>(&self, other: A) -> boolwhere A: JNIProvidesClassName,