Struct blackboxmc_java::util::JavaComparator
source · #[repr(C)]pub struct JavaComparator<'mc>(_, _);Expand description
A comparison function, which imposes a total ordering on some collection of objects. Comparators can be passed to a sort method (such as Collections.sort or Arrays.sort) to allow precise control over the sort order. Comparators can also be used to control the order of certain data structures (such as sorted sets or sorted maps), or to provide an ordering for collections of objects that don’t have a natural ordering.
The ordering imposed by a comparator c on a set of elements S is said to be consistent with equals if and only if c.compare(e1, e2)==0 has the same boolean value as e1.equals(e2) for every e1 and e2 in S.
Caution should be exercised when using a comparator capable of imposing an ordering inconsistent with equals to order a sorted set (or sorted map). Suppose a sorted set (or sorted map) with an explicit comparator c is used with elements (or keys) drawn from a set S. If the ordering imposed by c on S is inconsistent with equals, the sorted set (or sorted map) will behave "strangely." In particular the sorted set (or sorted map) will violate the general contract for set (or map), which is defined in terms of equals.
For example, suppose one adds two elements a and b such that (a.equals(b) && c.compare(a, b) != 0) to an empty TreeSet with comparator c. The second add operation will return true (and the size of the tree set will increase) because a and b are not equivalent from the tree set's perspective, even though this is contrary to the specification of the Set.add method.
Note: It is generally a good idea for comparators to also implement java.io.Serializable, as they may be used as ordering methods in serializable data structures (like TreeSet, TreeMap). In order for the data structure to serialize successfully, the comparator (if provided) must implement Serializable.
For the mathematically inclined, the relation that defines the imposed ordering that a given comparator c imposes on a given set of objects S is:
{(x, y) such that c.compare(x, y) <= 0}.
The quotient for this total order is:
{(x, y) such that c.compare(x, y) == 0}.
It follows immediately from the contract for compare that the quotient is an equivalence relation on S, and that the imposed ordering is a total order on S. When we say that the ordering imposed by c on S is consistent with equals, we mean that the quotient for the ordering is the equivalence relation defined by the objects' equals(Object) method(s):
{(x, y) such that x.equals(y)}.
Unlike Comparable, a comparator may optionally permit comparison of null arguments, while maintaining the requirements for an equivalence relation.
This interface is a member of the Java Collections Framework.
This is a representation of an abstract class.
Implementations
sourceimpl<'mc> JavaComparator<'mc>
impl<'mc> JavaComparator<'mc>
pub fn equals(&self, arg0: JObject<'mc>) -> Result<bool, Box<dyn Error>>
pub fn compare( &self, arg0: JObject<'mc>, arg1: JObject<'mc> ) -> Result<i32, Box<dyn Error>>
pub fn reverse_order( jni: &SharedJNIEnv<'mc> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn comparing_with_function( jni: &SharedJNIEnv<'mc>, arg0: impl Into<JavaFunction<'mc>>, arg1: Option<impl Into<JavaComparator<'mc>>> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn then_comparing_with_function( &self, arg0: impl Into<JavaFunction<'mc>>, arg1: Option<impl Into<JavaComparator<'mc>>> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn comparing_int( jni: &SharedJNIEnv<'mc>, arg0: impl Into<JavaToIntFunction<'mc>> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn comparing_long( jni: &SharedJNIEnv<'mc>, arg0: impl Into<JavaToLongFunction<'mc>> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn comparing_double( jni: &SharedJNIEnv<'mc>, arg0: impl Into<JavaToDoubleFunction<'mc>> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn reversed(&self) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn then_comparing_int( &self, arg0: impl Into<JavaToIntFunction<'mc>> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn then_comparing_long( &self, arg0: impl Into<JavaToLongFunction<'mc>> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn then_comparing_double( &self, arg0: impl Into<JavaToDoubleFunction<'mc>> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn natural_order( jni: &SharedJNIEnv<'mc> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn nulls_first( jni: &SharedJNIEnv<'mc>, arg0: impl Into<JavaComparator<'mc>> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn nulls_last( jni: &SharedJNIEnv<'mc>, arg0: impl Into<JavaComparator<'mc>> ) -> Result<JavaComparator<'mc>, Box<dyn Error>>
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>