pub struct JavaListIterator<'mc>(/* private fields */);Expand description
An iterator for lists that allows the programmer to traverse the list in either direction, modify the list during iteration, and obtain the iterator’s current position in the list. A ListIterator has no current element; its cursor position always lies between the element that would be returned by a call to previous() and the element that would be returned by a call to next(). An iterator for a list of length n has n+1 possible cursor positions, as illustrated by the carets (^) below:
Element(0) Element(1) Element(2) ... Element(n-1) cursor positions:^^^^^Note that the
remove() and set(Object) methods are not defined in terms of the cursor position; they are defined to operate on the last element returned by a call to next() or previous().
This interface is a member of the Java Collections Framework.
This is a representation of an abstract class.
Implementations
Sourceimpl<'mc> JavaListIterator<'mc>
impl<'mc> JavaListIterator<'mc>
pub fn add(&self, arg0: JObject<'mc>) -> Result<(), Box<dyn Error>>
pub fn remove(&self) -> Result<(), Box<dyn Error>>
pub fn has_next(&self) -> Result<bool, Box<dyn Error>>
pub fn next(&self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn set(&self, arg0: JObject<'mc>) -> Result<(), Box<dyn Error>>
pub fn next_index(&self) -> Result<i32, Box<dyn Error>>
pub fn previous_index(&self) -> Result<i32, Box<dyn Error>>
pub fn has_previous(&self) -> Result<bool, Box<dyn Error>>
pub fn previous(&self) -> Result<JObject<'mc>, Box<dyn Error>>
pub fn for_each_remaining( &self, arg0: impl Into<JavaConsumer<'mc>>, ) -> Result<(), Box<dyn Error>>
pub fn instance_of(&self, other: impl Into<String>) -> Result<bool, Error>